# Identify API Ruby

This gem provides simple API to make requests to the Split's Identify API.

## Installation

Add this gem to your Gemfile as usual:

```ruby
gem 'splitapi-rb'
```

## Usage

**Initialize client**

```ruby
client = SplitApi::Client.new(api_key: 'SPLIT_ADMIN_TOKEN', base_uri: 'SPLIT_IDENTIFY_BASE_URI')
```

**Make requests**

Now we have following models `Attributes`, `Environments`, `Identities`, `TrafficTypes`.

### Data Objects

Models can return the following:

- true/false (when `#delete` method was called)
- `SplitApi::DataObjects::Attribute`, `SplitApi::DataObjects::Environment`, `SplitApi::DataObjects::Identify` or `SplitApi::DataObjects::DataType`
- array of the above DTOs (when `#save_all` or `#list` was called)

Data objects structure:

#### Attribute DTO
```
#<SplitApi::DataObjects::Attribute
  @description="string",
  @display_name="string",
  @id="string",
  @is_searchable="true/false",
  @organization_id="string",
  @traffic_type_id="string"
>
```

#### Environment DTOs
```
#<SplitApi::DataObjects::Environment
  @name="string",
  @id="string",
>
```

#### Identity DTO
```
#<SplitApi::DataObjects::Identity
  @values="string",
  @key="string",
  @environment_id="string",
  @organization_id="string",
  @traffic_type_id="string",
  @timestamp="number"
>
```

#### TrafficType DTO
```
#<SplitApi::DataObjects::TrafficType
  @name="string",
  @id="string",
  @display_attribute_id="string"
>
```

### Attributes model

Available methods:

**list**: fetch all known attributes for traffic type

_arguments_: `traffic_type_id`

```ruby
client.attributes.list('traffic_type_id')
# example response:
[
  SplitApi::DataObjects::Attribute,
  # ...
]
```

**save**: create new attribute for traffic type

_arguments_: `attribute_hash`

```ruby
client.attributes.save(
  id: "string",
  traffic_type_id: "string",
  display_name: "string",
  description: "string",
  data_type: "string"
)
# example response:
SplitApi::DataObjects::Attribute
```

**delete**: delete attribute by key

_arguments_: `traffic_type_id`, `attribute_id`

```ruby
client.attributes.delete('traffic_type_id', 'attribute_id')
# example response:
true
```

### Environments model

Available methods:

**list**: fetch environments

_arguments_: none

```ruby
client.environments.list
# example response
[
  SplitApi::DataObjects::Environment,
  # ...
]
```

### Identities model

Available methods:

**save**: add identity

_arguments_: `identity_hash`

```ruby
client.identities.save(
  traffic_type_id: "string",
  environment_id: "string",
  key: "string",
  values: {
    key: "value"
  }
)
# example response:
SplitApi::DataObjects::Identity
```

**update**: update identity

_arguments_: `identity_hash`

```ruby
client.identities.update(
  traffic_type_id: "string",
  environment_id: "string",
  key: "string",
  values: {
    key: "value"
  }
)
# example response:
SplitApi::DataObjects::Identity
```

**save_all**: save multiple identities

_arguments_: `traffic_type_id`, `environment_id`, `identity_array`

```ruby
client.identities.save_all("string", "string",
  [
    {
      "traffic_type_id" => "string",
      "environment_id" => "string",
      "key" => "string",
      "values" => {
        "foo" => "bar"
      }
    },
    # ...
  ]
)
# example response:
{
  [
    SplitApi::DataObjects::Identity,
    # ...
  ],
  "failed": [],
  "metadata": {}
}
```

**delete**: delete all attributes of a specific key

_arguments_: `traffic_type_id`, `environment_id`, `key`

```ruby
client.identities.delete(`traffic_type_id`, `environment_id`, `key`)
# example response:
true
```

### Traffic Types model

Available methods:

**list**: list traffic types

_arguments_: none

```ruby
client.traffic_types.list
# example response:
[
  SplitApi::DataObjects::TrafficType
  # ...
]
```
